@@ -49,7 +49,7 @@ class Clade:
         else:
             self.cmds_file = os.path.abspath(cmds_file)
 
-        self.conf = conf if conf else dict()
+        self.conf = conf if conf else {"work_dir": self.work_dir}
         self.conf = merge_preset_to_conf(preset, self.conf)
         self.conf_file = os.path.join(self.work_dir, "conf.json")
 
@@ -144,7 +144,7 @@ class Clade:
 
         self.__prepare_to_intercept()
 
-        return intercept(
+        self.conf["build_exit_code"] = intercept(
             command=command,
             cwd=cwd,
             output=self.cmds_file,
@@ -154,6 +154,8 @@ class Clade:
             conf=self.conf
         )
 
+        return self.conf["build_exit_code"]
+
     def __get_ext_obj(self, ext_name):
         """Return object of specified extension."""
 
