@@ -31,6 +31,33 @@ class Storage(Extension):
 
     __version__ = "1"
 
+    @Extension.prepare
+    def parse(self, cmds_file):
+        files_to_add = self.conf.get("Storage.files_to_add", [])
+
+        if files_to_add:
+            self.log("Saving files")
+
+        for file in files_to_add:
+            file = os.path.abspath(file)
+            self.debug("Saving {!r} to the Storage".format(file))
+
+            if not os.path.exists(file):
+                self.error(
+                    "File does not exist: {!r}".format(file)
+                )
+                raise RuntimeError
+
+            if os.path.isfile(file):
+                self.add_file(file)
+                continue
+
+            for root, _, filenames in os.walk(file):
+                for filename in filenames:
+                    filename = os.path.join(root, filename)
+                    if not filename.startswith(self.clade_work_dir):
+                        self.add_file(filename)
+
     def add_file(self, filename, storage_filename=None, encoding=None):
         """Add file to the storage.
 
@@ -48,7 +75,7 @@ class Storage(Extension):
             else self.extensions["Path"].normalize_abs_path(filename)
         )
 
-        dst = self.work_dir + os.sep + storage_filename
+        dst = os.path.normpath(self.work_dir + os.sep + storage_filename)
 
         if self.__path_exists(dst):
             return
@@ -57,9 +84,13 @@ class Storage(Extension):
             self.__copy_file(filename, dst, encoding=encoding)
         except FileNotFoundError as e:
             self.debug(e)
+        except (PermissionError, OSError) as e:
+            self.log(e)
         except shutil.SameFileError:
             pass
 
+        return dst
+
     @functools.lru_cache(maxsize=30000)
     def __path_exists(self, path):
         return os.path.exists(path)
@@ -68,6 +99,7 @@ class Storage(Extension):
         os.makedirs(os.path.dirname(dst), exist_ok=True)
 
         if not self.conf.get("Storage.convert_to_utf8"):
+            self.debug("Storing {!r}".format(filename))
             shutil.copyfile(filename, dst)
         else:
             with open(filename, "rb") as fh:
@@ -90,15 +122,36 @@ class Storage(Extension):
                 shutil.copyfile(filename, dst)
                 return
 
+            self.debug("Trying to store {!r}. Detected encoding: {} (confidence = {})".format(
+                filename, encoding, confidence
+            ))
+
             with tempfile.NamedTemporaryFile(
                 mode="wb", delete=False
             ) as f:
                 # Encode file content to utf-8
-                content_bytes = content_bytes.decode(encoding).encode("utf-8")
+                try:
+                    content_bytes = content_bytes.decode(
+                        encoding,
+                        self.conf.get("Storage.decoding_errors", "strict")
+                    ).encode("utf-8")
+                except UnicodeDecodeError:
+                    # If user-specified encoding failed, try automatic detection
+                    if confidence == 1:
+                        self.__copy_file(filename, dst)
+                    # else: raise original exception
+                    else:
+                        raise
+
                 # Convert CRLF line endings to LF
                 content_bytes = content_bytes.replace(b"\r\n", b"\n")
                 f.write(content_bytes)
 
+            try:
+                shutil.copymode(filename, f.name)
+            except Exception:
+                self.warning("Couldn't set permissions for {!r}".format(filename))
+
             try:
                 os.replace(f.name, dst)
             except OSError:
@@ -107,11 +160,7 @@ class Storage(Extension):
     def get_storage_dir(self):
         return self.work_dir
 
-    def get_storage_path(self, path):
+    def get_storage_path(self, path) -> str:
         """Get path to the file or directory from the storage."""
         path = os.path.normpath(path)
         return os.path.join(self.work_dir, path.lstrip(os.path.sep))
-
-    @Extension.prepare
-    def parse(self, cmd_file):
-        super().parse(cmd_file)
